pub enum StrokeCap {
Butt,
Round,
Square,
}Expand description
Shape of the two ends of an open stroked path (an arc, today).
Variants
Butt
Flat end exactly at the geometric end of the path.
Round
Semicircular end bulging half the stroke width past the path end.
Square
Flat end projected half the stroke width past the path end.