pub enum StrokeJoin {
Miter,
Round,
Bevel,
}Expand description
Shape produced where two stroked segments meet at a corner.
Variants
Miter
Extend the outer edges until they meet in a sharp point.
Round
Fill the corner with a circular arc of half the stroke width.
Bevel
Cut the corner off with a straight chamfer.