pub enum CutDirection {
LeftToRight,
RightToLeft,
TopToBottom,
BottomToTop,
}Expand description
Direction of the gradient cut mask.
Variants
LeftToRight
Keep content from the left edge up to the cut progress.
RightToLeft
Keep content from the right edge up to the cut progress.
TopToBottom
Keep content from the top edge down to the cut progress.
BottomToTop
Keep content from the bottom edge up to the cut progress.